@@ -27,6 +27,8 @@
 #include "gmag-graphical-server.h"
 #include "GNOME_Magnifier.h"
 
+#include <unistd.h>
+
 #include <string.h>
 #include <stdlib.h>
 #include <sys/time.h>
@@ -179,7 +181,7 @@ magnifier_main_test_image (gpointer data)
 	CORBA_Environment ev;
 	GNOME_Magnifier_RectBounds roi;
 	int x_roi, y_roi;
-
+	
 	/* Only iterate the number of times specified */
 	if (global_options.timing_iterations > 0) {
 		if (timing_counter > global_options.timing_iterations) {
@@ -373,7 +375,7 @@ main (int argc, char** argv)
   guint pan_handle = 0, refresh_handle = 0;
   CORBA_Environment ev;
   Bonobo_PropertyBag properties;
-
+  
   Magnifier *magnifier;
   
   if (!bonobo_init (&argc, argv)) {
@@ -403,7 +405,7 @@ main (int argc, char** argv)
 	  string = g_strconcat ("DISPLAY=", global_options.target_display, NULL);
 	  putenv (string);
   } else {
-		  global_options.target_display = getenv ("DISPLAY");
+		  global_options.target_display = g_getenv ("DISPLAY");
 		  if (!global_options.target_display) {
 			  fprintf (stderr, _("Can't open display: DISPLAY is not set"));
 			  exit (1);
@@ -436,15 +438,15 @@ main (int argc, char** argv)
   properties = GNOME_Magnifier_Magnifier_getProperties (
 	  BONOBO_OBJREF (magnifier), &ev);
   if (ev._major != CORBA_NO_EXCEPTION) fprintf (stderr, "EXCEPTION\n");
+  
+  if (global_options.target_display)
+	  bonobo_pbclient_set_string (properties, "target-display-screen",
+				      global_options.target_display, NULL);
 
   if (global_options.source_display)
 	  bonobo_pbclient_set_string (properties, "source-display-screen",
 				      global_options.source_display, NULL);
 
-  if (global_options.target_display)
-	  bonobo_pbclient_set_string (properties, "target-display-screen",
-				      global_options.target_display, NULL);
-
   if (global_options.cursor_set)
 	  bonobo_pbclient_set_string (properties, "cursor-set",
 				      global_options.cursor_set, NULL);
